//                                               -*- C++ -*-
/**
 *  @file  InverseNatafEllipticalDistributionGradient.cxx
 *  @brief Class for the InverseNataf transformation gradient for elliptical
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: InverseNatafEllipticalDistributionGradient.cxx 1473 2010-02-04 15:44:49Z dutka $
 */
#include "OTprivate.hxx"
#include "InverseNatafEllipticalDistributionGradient.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {


      /*
       * @class InverseNatafEllipticalDistributionGradient
       *
       * This class offers an interface for the InverseNataf function for elliptical distributions
       */

      CLASSNAMEINIT(InverseNatafEllipticalDistributionGradient);

      /* Parameter constructor */
      InverseNatafEllipticalDistributionGradient::InverseNatafEllipticalDistributionGradient(const SquareMatrix & cholesky):
	ConstantNumericalMathGradientImplementation(cholesky.transpose())
      {
	// Nothing to do
      }

      /* String converter */
      String InverseNatafEllipticalDistributionGradient::__repr__() const
      {
	return OSS() << "class=" << InverseNatafEllipticalDistributionGradient::GetClassName()
		     << " cholesky=" << getConstant().transpose();
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
