//                                               -*- C++ -*-
/**
 *  @file  InverseNatafEllipticalDistributionHessian.cxx
 *  @brief Class for the InverseNataf transformation hessian for elliptical
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: InverseNatafEllipticalDistributionHessian.cxx 1473 2010-02-04 15:44:49Z dutka $
 */
#include "OTprivate.hxx"
#include "InverseNatafEllipticalDistributionHessian.hxx"
#include "SymmetricTensor.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {


      /*
       * @class InverseNatafEllipticalDistributionHessian
       *
       * This class offers an interface for the InverseNataf function for elliptical distributions
       */

      CLASSNAMEINIT(InverseNatafEllipticalDistributionHessian);

      /* Parameter constructor */
      InverseNatafEllipticalDistributionHessian::InverseNatafEllipticalDistributionHessian(const UnsignedLong dimension):
	ConstantNumericalMathHessianImplementation(OT::Base::Type::SymmetricTensor(dimension, dimension))
      {
	// Nothing to do
      }

      /* String converter */
      String InverseNatafEllipticalDistributionHessian::__repr__() const
      {
	return OSS() << "class=" << InverseNatafEllipticalDistributionHessian::GetClassName();
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
